#!/usr/bin/env python
# -*- coding: utf-8 -*-

#                        __    __           _     
#   _      ______  _____/ /___/ /________  (_)___ 
#  | | /| / / __ \/ ___/ / __  / ___/ __ \/ / __ \
#  | |/ |/ / /_/ / /  / / /_/ / /__/ /_/ / / / / /
#  |__/|__/\____/_/  /_/\__,_/\___/\____/_/_/ /_/


__title__   = 'worldcoin'
__version__ = '0.5.2'
__author__  = "@c0ding"
__repo__    = "https://github.com/c0ding/worldcoin-api"
__license__ = "Apache v2.0 License"

import worldcoin_utils
from worldcoin_api import (
	about, difficulty, hashrate, block_count, total_coins, reward,
	block_hash, transaction, address, to_btc, to_usd
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
import urllib
from worldcoin_utils import exchange
from worldcoin_utils import blockexplorer

__title__   = 'worldcoin'
__version__ = '0.5.2'
__author__  = "@c0ding"
__repo__    = "https://github.com/c0ding/worldcoin-api"
__license__ = "Apache v2.0 License"


def about():
	return "{} v.{} is maintained by {} and available at {}.".format(__title__, __version__, __author__, __repo__)


def difficulty():
	"""Returns the current network difficulty."""

	d = urllib.urlopen(blockexplorer('coindetails'))
	d = json.loads(d.read())
	return d[u'Difficulty']


def hashrate():
	"""Returns the current network hashrate."""
	
	d = urllib.urlopen(blockexplorer('coindetails'))
	d = json.loads(d.read())
	return d[u'HashRate']


def block_count():
	"""Returns the number of blocks in the longest block chain.
	   Equivalent to Bitcoin's getblockcount.
	"""

	d = urllib.urlopen(blockexplorer('coindetails'))
	d = json.loads(d.read())
	return d[u'Blocks']


def total_coins():
	"""Returns the number of Worldcoin mined."""
	
	d = urllib.urlopen(blockexplorer('coindetails'))
	d = json.loads(d.read())
	return d[u'TotalCoins']

	
def reward():
	"""Returns the current block reward."""

	d = block_hash()
	e = d[u'Transactions']
	for item in e:
		f = transaction(item)
		g = f[u'Outputs']
		reward = g[0]['Amount']
		return reward


def block_hash(PARAMETER=None):
	"""Returns the block hash at a specific height.
	   [PARAMETER] is optional, should be a block hash or height.
	   [DEFAULT] equals to last block.
	"""
	if not PARAMETER:
		d = urllib.urlopen(blockexplorer('block'))
		return json.loads(d.read())
	else:
		d = urllib.urlopen(blockexplorer('block') + '/' + str(PARAMETER))
		return json.loads(d.read())
	

def transaction(PARAMETER):
	"""Returns details of a specific transaction.
	   [PARAMETER] is required and should be a transaction hash.
	"""

	d = urllib.urlopen(blockexplorer('transaction') + '/' + str(PARAMETER))
	return json.loads(d.read())


def address(PARAMETER):
	"""Returns details of a specific address.
	   [PARAMETER] is required and should be an address hash.
	"""

	d = urllib.urlopen(blockexplorer('address') + '/' + str(PARAMETER))
	return json.loads(d.read())


def to_btc():
	"""Returns array with trading pair object."""
	
	d = urllib.urlopen(exchange('wdc_btc'))
	return json.loads(d.read())
	
	
def to_usd():
	"""Returns array with trading pair object."""
	
	d = urllib.urlopen(exchange('wdc_usd'))
	return json.loads(d.read())



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
sys.path.insert(0, os.path.abspath('..'))
import unittest
import worldcoin

__title__   = 'worldcoin'
__version__ = '0.5.2'
__author__  = "@c0ding"
__repo__    = "https://github.com/c0ding/worldcoin-api"
__license__ = "Apache v2.0 License"

class worldcointestsuite(unittest.TestCase):

	_multiprocess_can_split_ = True

	def test_difficulty(self):
		worldcoin.difficulty()
		assert type(worldcoin.difficulty()) is float
		
	def test_hashrate(self):
		worldcoin.hashrate()
		assert type(worldcoin.hashrate()) is int

	def test_block_count(self):
		worldcoin.block_count()
		assert type(worldcoin.block_count()) is int

	def test_total_coins(self):
		worldcoin.total_coins()
		assert type(worldcoin.total_coins()) is float
		
	def test_reward(self):
		worldcoin.reward()
		assert type(worldcoin.reward()) is float
	
	def test_block_hash(self):
		worldcoin.block_hash()
		assert type(worldcoin.block_hash()) is dict
		
	def test_transaction(self):
		worldcoin.transaction('0fc36e386282295512aa63d9f5047d9dc305c983394803474cfaa2f99d7e1bd0')
		assert type(worldcoin.transaction('0fc36e386282295512aa63d9f5047d9dc305c983394803474cfaa2f99d7e1bd0')) is dict

	def test_address(self):
		worldcoin.address('WYJ142WhSViiCJuUB2JbpbNiCFAuk9B47z')
		assert type(worldcoin.address('WYJ142WhSViiCJuUB2JbpbNiCFAuk9B47z')) is dict
		
	def test_to_btc(self):
		worldcoin.to_btc()
		assert type(worldcoin.to_btc()) is dict

	def test_to_usd(self):
		worldcoin.to_usd()
		assert type(worldcoin.to_usd()) is dict

if __name__ == '__main__':
    unittest.main()
